"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getClosestMatchingVersion = void 0;
var semver_1 = require("semver");
/**
 * Gets the closest matching package version info.
 *
 * @param availableVersions
 * @param version
 */
function getClosestMatchingVersion(availableVersions, version) {
    var parsedVersion = parseVersion(version);
    if (!parsedVersion) {
        return availableVersions[0];
    }
    var bestMatch = availableVersions.find(function (v) {
        var parsedAvailableVersion = parseVersion(v.version);
        if (!parsedAvailableVersion) {
            return false;
        }
        if (parsedVersion.major !== parsedAvailableVersion.major) {
            return false;
        }
        if (parsedVersion.minor !== parsedAvailableVersion.minor) {
            return false;
        }
        return true;
    });
    return bestMatch || availableVersions[0];
}
exports.getClosestMatchingVersion = getClosestMatchingVersion;
/**
 * Parses the version if possible.
 *
 * @param version
 * @returns
 */
function parseVersion(version) {
    return (0, semver_1.parse)(cleanVersion(version));
}
/**
 * Cleans the version of any semver range specifiers.
 * @param version
 * @returns
 */
function cleanVersion(version) {
    return version.replace(/^[\^~=\s]/, '');
}
//# sourceMappingURL=versioning.js.map